==> apache-camel-quarkus-3.14.0-src.zip: camel-quarkus-3.14.0/integration-tests/langchain4j-chat/src/test/java/org/apache/camel/quarkus/component/langchain4j/chat/it/LangChain4jChatTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.quarkus.component.langchain4j.chat.it;

import io.quarkus.test.common.WithTestResource;
import io.quarkus.test.junit.QuarkusTest;
import io.restassured.RestAssured;
import org.junit.jupiter.api.Test;

@QuarkusTest
@WithTestResource(OllamaTestResource.class)
class LangChain4jChatTest {

    @Test
    void simpleMessage() {
        RestAssured.get("/langchain4j-chat/simple-message")
                .then()
                .statusCode(200);
    }

    @Test
    void promptMessage() {
        RestAssured.get("/langchain4j-chat/prompt-message")
                .then()
                .statusCode(200);
    }

    @Test
    void multipleMessages() {
        RestAssured.get("/langchain4j-chat/multiple-messages")
                .then()
                .statusCode(200);
    }
}

==> apache-camel-quarkus-3.20.4-src.zip: camel-quarkus-3.20.4/integration-tests/langchain4j-chat/src/test/java/org/apache/camel/quarkus/component/langchain4j/chat/it/LangChain4jChatTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.quarkus.component.langchain4j.chat.it;

import io.quarkus.test.common.QuarkusTestResource;
import io.quarkus.test.junit.QuarkusTest;
import io.restassured.RestAssured;
import org.junit.jupiter.api.Test;

@QuarkusTest
@QuarkusTestResource(OllamaTestResource.class)
class LangChain4jChatTest {

    @Test
    void simpleMessage() {
        RestAssured.get("/langchain4j-chat/simple-message")
                .then()
                .statusCode(200);
    }

    @Test
    void promptMessage() {
        RestAssured.get("/langchain4j-chat/prompt-message")
                .then()
                .statusCode(200);
    }

    @Test
    void multipleMessages() {
        RestAssured.get("/langchain4j-chat/multiple-messages")
                .then()
                .statusCode(200);
    }
}
